@@ -1,11 +1,10 @@
 
 /*
- * Python 2/3 bindings for libfiu
+ * Python 3 bindings for libfiu
  * Alberto Bertogli (albertito@blitiri.com.ar)
  *
  * This is the low-level module, used by the python one to construct
- * friendlier objects. It support both Python 2 and 3, assuming the constants
- * PYTHON2 and PYTHON3 are defined accordingly.
+ * friendlier objects.
  */
 
 #include <Python.h>
@@ -13,9 +12,8 @@
 /* Unconditionally enable fiu, otherwise we get fake headers */
 #define FIU_ENABLE 1
 
-#include <fiu.h>
 #include <fiu-control.h>
-
+#include <fiu.h>
 
 static PyObject *fail(PyObject *self, PyObject *args)
 {
@@ -56,7 +54,7 @@ static PyObject *enable(PyObject *self, PyObject *args)
 	unsigned int flags;
 
 	if (!PyArg_ParseTuple(args, "siOI:enable", &name, &failnum, &failinfo,
-				&flags))
+	                      &flags))
 		return NULL;
 
 	/* The caller will guarantee that failinfo doesn't dissapear from under
@@ -73,18 +71,17 @@ static PyObject *enable_random(PyObject *self, PyObject *args)
 	double probability;
 
 	if (!PyArg_ParseTuple(args, "siOId:enable_random", &name, &failnum,
-				&failinfo, &flags, &probability))
+	                      &failinfo, &flags, &probability))
 		return NULL;
 
 	/* The caller will guarantee that failinfo doesn't dissapear from under
 	 * our feet. */
-	return PyLong_FromLong(fiu_enable_random(name, failnum, failinfo,
-				flags, probability));
+	return PyLong_FromLong(
+	    fiu_enable_random(name, failnum, failinfo, flags, probability));
 }
 
-
 static int external_callback(const char *name, int *failnum, void **failinfo,
-		unsigned int *flags)
+                             unsigned int *flags)
 {
 	int rv;
 	PyObject *cbrv;
@@ -114,7 +111,7 @@ static int external_callback(const char *name, int *failnum, void **failinfo,
 		return 0;
 	}
 
-	cbrv = PyEval_CallObject(*failinfo, args);
+	cbrv = PyObject_CallObject(*failinfo, args);
 	Py_DECREF(args);
 
 	if (cbrv == NULL) {
@@ -141,7 +138,7 @@ static PyObject *enable_external(PyObject *self, PyObject *args)
 	PyObject *py_external_cb;
 
 	if (!PyArg_ParseTuple(args, "siIO:enable_external", &name, &failnum,
-				&flags, &py_external_cb))
+	                      &flags, &py_external_cb))
 		return NULL;
 
 	if (!PyCallable_Check(py_external_cb)) {
@@ -156,8 +153,8 @@ static PyObject *enable_external(PyObject *self, PyObject *args)
 	 * Similar to the way failinfo is handled, we DO NOT TOUCH THE RC OF
 	 * THE EXTERNAL CALLBACK, assuming the caller will take care of making
 	 * sure it doesn't dissapear from beneath us. */
-	return PyLong_FromLong(fiu_enable_external(name, failnum,
-				py_external_cb, flags, external_callback));
+	return PyLong_FromLong(fiu_enable_external(
+	    name, failnum, py_external_cb, flags, external_callback));
 }
 
 static PyObject *enable_stack_by_name(PyObject *self, PyObject *args)
@@ -169,14 +166,13 @@ static PyObject *enable_stack_by_name(PyObject *self, PyObject *args)
 	char *func_name;
 	int pos_in_stack = -1;
 
-	if (!PyArg_ParseTuple(args, "siOIs|i:enable_stack_by_name",
-				&name, &failnum, &failinfo, &flags,
-				&func_name, &pos_in_stack))
+	if (!PyArg_ParseTuple(args, "siOIs|i:enable_stack_by_name", &name,
+	                      &failnum, &failinfo, &flags, &func_name,
+	                      &pos_in_stack))
 		return NULL;
 
-	return PyLong_FromLong(fiu_enable_stack_by_name(name, failnum,
-				failinfo, flags,
-				func_name, pos_in_stack));
+	return PyLong_FromLong(fiu_enable_stack_by_name(
+	    name, failnum, failinfo, flags, func_name, pos_in_stack));
 }
 
 static PyObject *disable(PyObject *self, PyObject *args)
@@ -211,49 +207,34 @@ static PyObject *rc_fifo(PyObject *self, PyObject *args)
 }
 
 static PyMethodDef fiu_methods[] = {
-	{ "fail", (PyCFunction) fail, METH_VARARGS, NULL },
-	{ "failinfo", (PyCFunction) failinfo, METH_VARARGS, NULL },
-	{ "enable", (PyCFunction) enable, METH_VARARGS, NULL },
-	{ "enable_random", (PyCFunction) enable_random, METH_VARARGS, NULL },
-	{ "enable_external", (PyCFunction) enable_external,
-		METH_VARARGS, NULL },
-	{ "enable_stack_by_name", (PyCFunction) enable_stack_by_name,
-		METH_VARARGS, NULL },
-	{ "disable", (PyCFunction) disable, METH_VARARGS, NULL },
-	{ "set_prng_seed", (PyCFunction) set_prng_seed, METH_VARARGS, NULL },
-	{ "rc_fifo", (PyCFunction) rc_fifo, METH_VARARGS, NULL },
-	{ NULL }
-};
+    {"fail", (PyCFunction)fail, METH_VARARGS, NULL},
+    {"failinfo", (PyCFunction)failinfo, METH_VARARGS, NULL},
+    {"enable", (PyCFunction)enable, METH_VARARGS, NULL},
+    {"enable_random", (PyCFunction)enable_random, METH_VARARGS, NULL},
+    {"enable_external", (PyCFunction)enable_external, METH_VARARGS, NULL},
+    {"enable_stack_by_name", (PyCFunction)enable_stack_by_name, METH_VARARGS,
+     NULL},
+    {"disable", (PyCFunction)disable, METH_VARARGS, NULL},
+    {"set_prng_seed", (PyCFunction)set_prng_seed, METH_VARARGS, NULL},
+    {"rc_fifo", (PyCFunction)rc_fifo, METH_VARARGS, NULL},
+    {NULL}};
 
-#ifdef PYTHON3
 static PyModuleDef fiu_module = {
-	PyModuleDef_HEAD_INIT,
-	.m_name = "libfiu",
-	.m_size = -1,
-	.m_methods = fiu_methods,
+    PyModuleDef_HEAD_INIT,
+    .m_name = "libfiu",
+    .m_size = -1,
+    .m_methods = fiu_methods,
 };
-#endif
 
-#ifdef PYTHON2
-PyMODINIT_FUNC initfiu_ll(void)
-#else
 PyMODINIT_FUNC PyInit_fiu_ll(void)
-#endif
 {
 	PyObject *m;
 
-#ifdef PYTHON2
-	m = Py_InitModule("fiu_ll", fiu_methods);
-#else
 	m = PyModule_Create(&fiu_module);
-#endif
 
 	PyModule_AddIntConstant(m, "FIU_ONETIME", FIU_ONETIME);
 
 	fiu_init(0);
 
-#ifdef PYTHON3
 	return m;
-#endif
 }
-
