@@ -11,6 +11,9 @@ extern int __thread _fiu_called;
 /* Get a symbol from libc */
 void *libc_symbol(const char *symbol);
 
+/* Record internally an error for a stream */
+void set_ferror(void * stream);
+
 /* Some compilers support constructor priorities. Since we don't rely on them,
  * but use them for clarity purposes, use a macro so libfiu builds on systems
  * where they're not supported.
@@ -75,9 +78,9 @@ void *libc_symbol(const char *symbol);
 
 /* Generates the init part of the wrapped function */
 #define mkwrap_init(RTYPE, NAME, PARAMS, PARAMST) \
-	static RTYPE (*_fiu_orig_##NAME) PARAMS = NULL;		\
+	static __thread RTYPE (*_fiu_orig_##NAME) PARAMS = NULL;		\
 								\
-	static int _fiu_in_init_##NAME = 0;			\
+	static __thread int _fiu_in_init_##NAME = 0;			\
 								\
 	static void constructor_attr(201) _fiu_init_##NAME(void) \
 	{							\
@@ -92,7 +95,7 @@ void *libc_symbol(const char *symbol);
 	}
 
 /* Generates the definition part of the wrapped function. */
-#define mkwrap_def(RTYPE, NAME, PARAMS, PARAMST) \
+#define mkwrap_def(RTYPE, NAME, PARAMS) \
 	RTYPE NAME PARAMS					\
 	{ 							\
 		RTYPE r;					\
@@ -122,7 +125,7 @@ void *libc_symbol(const char *symbol);
 /* Generates the common top for most functions (init + def + body called) */
 #define mkwrap_top(RTYPE, NAME, PARAMS, PARAMSN, PARAMST, ON_ERR) \
 	mkwrap_init(RTYPE, NAME, PARAMS, PARAMST) \
-	mkwrap_def(RTYPE, NAME, PARAMS, PARAMST) \
+	mkwrap_def(RTYPE, NAME, PARAMS) \
 	mkwrap_body_called(NAME, PARAMSN, ON_ERR)
 
 /* Generates the body of the function for normal, non-errno usage. The return
@@ -166,6 +169,24 @@ void *libc_symbol(const char *symbol);
 			goto exit;				\
 		}
 
+/* As mkwrap_body_errno, but calls set_ferror for the given stream. */
+#define mkwrap_body_errno_ferror(FIU_NAME, FAIL_RET, STREAM) \
+								\
+		fstatus = fiu_fail(FIU_NAME);			\
+		if (fstatus != 0) {				\
+			void *finfo = fiu_failinfo();		\
+			if (finfo == NULL) {			\
+				errno = valid_errnos[random() % \
+					sizeof(valid_errnos) / sizeof(int)]; \
+			} else {				\
+				errno = (long) finfo;		\
+			}					\
+			r = FAIL_RET;				\
+			printd("failing\n");			\
+			set_ferror(STREAM); \
+			goto exit;				\
+		}
+
 /* Generates a body part that will reduce the CNT parameter in a random
  * amount when the given point of failure is enabled. Can be combined with the
  * other body generators. */
