@@ -12,6 +12,10 @@ set -ex
 ./wrap fiu-run -c "enable name=p1" true
 
 # open() failure.
-! ./wrap fiu-run -x -c "enable name=posix/io/oc/open" cat /dev/null
+( ! ./wrap fiu-run -x -c "enable name=posix/io/oc/open" cat /dev/null )
 
+# Deprecated option: -e.
+( ! ./wrap fiu-run -x -e "posix/io/oc/open" cat /dev/null )
 
+# Deprecated option: -p.
+( ! ./wrap fiu-run -x -e "posix/io/oc/open" -p 1 cat /dev/null )
